/******************************************************************************
* File Name: diode.h
*  Version 2.1
*
* Description:
*  This file contains defines and function prototype for temperature measurement 
*  using Diode sensor
*
* Note:
*
********************************************************************************
* Copyright (2012), Cypress Semiconductor Corporation. All Rights Reserved.
********************************************************************************
* This software is owned by Cypress Semiconductor Corporation (Cypress)
* and is protected by and subject to worldwide patent protection (United
* States and foreign), United States copyright laws and international treaty
* provisions. Cypress hereby grants to licensee a personal, non-exclusive,
* non-transferable license to copy, use, modify, create derivative works of,
* and compile the Cypress Source Code and derivative works for the sole
* purpose of creating custom software in support of licensee product to be
* used only in conjunction with a Cypress integrated circuit as specified in
* the applicable agreement. Any reproduction, modification, translation,
* compilation, or representation of this software except as specified above 
* is prohibited without the express written permission of Cypress.
*
* Disclaimer: CYPRESS MAKES NO WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, WITH 
* REGARD TO THIS MATERIAL, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED 
* WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
* Cypress reserves the right to make changes without further notice to the 
* materials described herein. Cypress does not assume any liability arising out 
* of the application or use of any product or circuit described herein. Cypress 
* does not authorize its products for use as critical components in life-support 
* systems where a malfunction or failure may reasonably be expected to result in 
* significant injury to the user. The inclusion of Cypress' product in a life-
* support systems application implies that the manufacturer assumes all risk of 
* such use and in doing so indemnifies Cypress against all charges. 
*
* Use of this Software may be limited by and subject to the applicable Cypress
* software license agreement. 
*******************************************************************************/
#if !defined(DIODE_H)
#define DIODE_H

#include <math.h>  
#include "filter.h"
#include "temp.h"
#include "calibration.h"

/* Filter coefficient for sensors */
#define DIODE_CAL_FILTER_COEFF          64 
#define DIODE_FILTER_COEFF              64

/* Defines for ADC MUX channels */
#define DIODE_CHANNEL                   2

/* Defines for IDAC current Mux */
#define DIODE_1_IDAC_CHANNEL            2
#define DIODE_2_IDAC_CHANNEL            3

/* Ideality factor for diode η, typically this value varies from 1.001 to 1.01 */
#define IDEALITY_FACTOR                 ((float)1.004)

/* Diode constant , this is q/(η*k) ratio, 
 * q = magnitude of electronic charge(1.602 * 10e-19)
 * k = Boltzmanns constant(1.38 * 10e-23)
 * η = Ideality factor for diode
 * see Cypress AN60590 for more details */
#define DIODE_CONSTANT                  ((float)11608.69)/IDEALITY_FACTOR

/* Function prototype to measure temperature using diode 1 sensor*/
float MeasureFirstDiodeTemp(void);

/* Function prototype to measure temperature using diode 2 sensor*/
float MeasureSecondDiodeTemp(void);

#endif /* DIODE_H */

/* [] END OF FILE */


