/******************************************************************************
* File Name: thermistor.h
*  Version 2.1
*
* Description:
*  This file contains defines and function prototype for temperature measurement 
*  using thermistor sensor
*
* Note:
*
********************************************************************************
* Copyright (2012), Cypress Semiconductor Corporation. All Rights Reserved.
********************************************************************************
* This software is owned by Cypress Semiconductor Corporation (Cypress)
* and is protected by and subject to worldwide patent protection (United
* States and foreign), United States copyright laws and international treaty
* provisions. Cypress hereby grants to licensee a personal, non-exclusive,
* non-transferable license to copy, use, modify, create derivative works of,
* and compile the Cypress Source Code and derivative works for the sole
* purpose of creating custom software in support of licensee product to be
* used only in conjunction with a Cypress integrated circuit as specified in
* the applicable agreement. Any reproduction, modification, translation,
* compilation, or representation of this software except as specified above 
* is prohibited without the express written permission of Cypress.
*
* Disclaimer: CYPRESS MAKES NO WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, WITH 
* REGARD TO THIS MATERIAL, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED 
* WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
* Cypress reserves the right to make changes without further notice to the 
* materials described herein. Cypress does not assume any liability arising out 
* of the application or use of any product or circuit described herein. Cypress 
* does not authorize its products for use as critical components in life-support 
* systems where a malfunction or failure may reasonably be expected to result in 
* significant injury to the user. The inclusion of Cypress' product in a life-
* support systems application implies that the manufacturer assumes all risk of 
* such use and in doing so indemnifies Cypress against all charges. 
*
* Use of this Software may be limited by and subject to the applicable Cypress
* software license agreement. 
*******************************************************************************/
#if !defined(THERMISTOR_H)
#define THERMISTOR_H

#include <math.h>
#include "temp.h"
#include "calibration.h"
#include <stdio.h>

/* Thermistor Reference resistor */
#define THERMISTOR_REF_RES               10000.0

/* Steinhart-Hart A,B and C coefficient value for the thermistor used for this
   project, This value is derived by measuring or known value of thermistor at 
   3 different temperatures points(-20,+25,+80 degree Celsius) */
#define STEIN_CO_A                      0.0008731007
#define STEIN_CO_B                      0.0002539631
#define STEIN_CO_C                      1.815255E-07

/* Defines for ADC MUX channels */

#define THERM_SIGNAL_CHANNEL            3
#define THERM_REF_CHANNEL               4


/* Function prototype to measure temperature using thermistor */
float MeasureThermistorTemp(void);

/* Function prototype to get thermistor resistance */
float ThermistorGetResistance(void);

/* Function prototype to convert thermistor resistance to temperature */
float ThermistorRestoTemp(float thermRes);


#endif /* THERMISTOR_H */
