/******************************************************************************
* File Name: thermocouple.h
*  Version 2.1
*
* Description:
*  This file contains defines and function prototype for temperature measurement 
*  using thermocouple
*
* Note:
*
********************************************************************************
* Copyright (2012), Cypress Semiconductor Corporation. All Rights Reserved.
********************************************************************************
* This software is owned by Cypress Semiconductor Corporation (Cypress)
* and is protected by and subject to worldwide patent protection (United
* States and foreign), United States copyright laws and international treaty
* provisions. Cypress hereby grants to licensee a personal, non-exclusive,
* non-transferable license to copy, use, modify, create derivative works of,
* and compile the Cypress Source Code and derivative works for the sole
* purpose of creating custom software in support of licensee product to be
* used only in conjunction with a Cypress integrated circuit as specified in
* the applicable agreement. Any reproduction, modification, translation,
* compilation, or representation of this software except as specified above 
* is prohibited without the express written permission of Cypress.
*
* Disclaimer: CYPRESS MAKES NO WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, WITH 
* REGARD TO THIS MATERIAL, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED 
* WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
* Cypress reserves the right to make changes without further notice to the 
* materials described herein. Cypress does not assume any liability arising out 
* of the application or use of any product or circuit described herein. Cypress 
* does not authorize its products for use as critical components in life-support 
* systems where a malfunction or failure may reasonably be expected to result in 
* significant injury to the user. The inclusion of Cypress' product in a life-
* support systems application implies that the manufacturer assumes all risk of 
* such use and in doing so indemnifies Cypress against all charges. 
*
* Use of this Software may be limited by and subject to the applicable Cypress
* software license agreement. 
*******************************************************************************/
#if !defined(THERMOCOUPLE_H)
#define THERMOCOUPLE_H

#include "filter.h"
#include "calibration.h"

/* Defines for ADC MUX channels */
#define TC_HOT_JN_CHANNEL               5
#define IC_CHANNEL              		6

/* Filter coefficient for sensors */
#define TC_FILTER_COEFF                 16

/* Zero degree offset voltage of DS600(509 mv from sensor datasheet) */
#define ZERO_DEGREE_OFFSET_VOLTAGE      ((float) 509.0)

/* Temperature coefficient for DS600,(6.45mv/degree C from sensor datasheet) */
#define VOLTAGE_PER_DEGREE              ((float) 6.45)

/* Function to measure DS600 IC temperature which is used for Thermocouple
   cold Junction compensation */
float MeasureICTemp(void);

/* Function prototype to convert cold junction temperature to TC micro volts */
float ColdJnTempTomVolts(float temp);

/* Function prototype to convert thermocouple volts to temperature */
float TcmVoltsToTemp(float TcmVolt);

/* Function prototype to measure temperature using thermocouple*/
float MeasureThermoCoupleTemp(void);

/* Function to select cold junction sensor, IC or thermistor */
float MeasureColdJnSensorTemp(void);

/* Flag to toggle CJ selection between thermistor and IC */
extern uint8 CJSelectFlag;

#endif /* THERMOCOUPLE_H */

/* [] END OF FILE */

                              